<?php

declare(strict_types=1);

use PrestaShop\Module\PolarisPrestaConnector\BridgeAdapter;
use PrestaShop\Module\PolarisPrestaConnector\SyncConfiguration;
use PrestaShop\PrestaShop\Adapter\SymfonyContainer;

if (!defined('_PS_VERSION_'))
  exit;

define('_TPL_PATH', '@Modules/prestaconnector/views/templates/');


class PolarisPrestaConnector extends Module
{
    /**
     * Identifiant du module
     */
    public string $Id;

    /**
     * Préfixe des tables
     */
    public string $TblPrefix;

     /**
     * Configuration du module
     *      
     */
    private ?SyncConfiguration $cfg = null;

    /**
     * Lien vers le pont
     */
    private ?BridgeAdapter $bridge = null;
    

     /**
     * New instance
     * 
     */
    public function __construct()
    {
        // On va se noter une constante pour identifier la version de notre module
        // Cette constante, nommée Id est composée des 3 premieres lettres du nom du module
        $this->Id = substr(basename(__FILE__), 0, 3);
        if ($this->Id == 'pre')
            $this->Id = 'pol';

        $this->TblPrefix = _DB_PREFIX_ . 'pc_' . $this->Id . '_';
        
        $this->name = basename(__FILE__, '.php');
        $this->author = 'VEGA Informatique';
                
        $this->version = '0.1';

        $this->tab = 'synchronisation';        
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '8.0.0',
            'max' => _PS_VERSION_,
        ];
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->trans('PolarisPrestaConnector', [], 'Modules.prestaconnector.Admin');
        $this->description = $this->trans('This module provide sync between your Prestashop and your backoffice © VEGA Informatique.', [], 'Modules.prestaconnector.Admin');

        $this->confirmUninstall = $this->trans('Are you sure you want to uninstall this module ?', [], 'Modules.Polarisprestaconnector.Admin');

        // Faut-il déclencher la mise à jour de la base de données du module ?
        // pour le savoir on regarde, si la version enregistrée dans la configuration est inférieure à la version actuelle                
        $currentDbVersion = \Configuration::get($this->name . '_version');
        if (!$currentDbVersion)
            $currentDbVersion = '0.0';

        if (version_compare($currentDbVersion, $this->version) < 0) {            
            // On met à jour la version du module
            require_once _PS_MODULE_DIR_ . $this->name . '/db/upgrade.php';
            $upgrade = new \PrestaShop\Module\PolarisPrestaConnector\Upgrade();
            $upgrade->upgradeModule($this, $currentDbVersion);
        }
    }

    public function install()
    {
        return parent::install()
         && $this->registerHook('dashboardZoneOne')
         && $this->registerHook('displayBackOfficeHeader');
    }

    public function uninstall()
    {

    }

    /**
     * Obtenir l'objet de configuration
     */
    public function getCfg() : SyncConfiguration
    {
        if (!$this->cfg)
            $this->cfg = new SyncConfiguration($this);

        return $this->cfg;
    }

    /**
     * Obtient le pont configuré
     */
    public function getBridge() : BridgeAdapter
    {
        if (!$this->bridge)
        {
            $classname = "PrestaShop\\Module\\PolarisPrestaConnector\\" . $this->Id . "\\Bridge";

            $this->bridge = new $classname($this->getCfg());            
        }
        return $this->bridge;
    }

    /*
    * Page de configuration
    */
    public function getContent()
    {
        Tools::redirectAdmin(
            SymfonyContainer::getInstance()->get('router')->generate('prestaconnector_configuration')
        );
    }


    public function hookDashboardZoneOne($params)
	{
        $router = SymfonyContainer::getInstance()->get('router');
        $tpl_variables = array(
            'module_version' => $this->version,
            'configUrl'=> $router->generate("prestaconnector_configuration"),
            //'statusUrl'=> $router->generate("prestaconnector_status"),
            'logsUrl' => $this->context->link->getAdminLink("AdminLogs")
        );

        return $this->get('twig')->render(_TPL_PATH . 'hook/dashboard.html.twig', $tpl_variables);
	}


    public function hookDisplayBackOfficeHeader()
    {
        $this->context->controller->addJS($this->_path.'views/js/admin.js');
        $this->context->controller->addCSS($this->_path.'views/css/admin.css');
    }


}